# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from ... import _utilities
from . import outputs
from ... import meta as _meta

__all__ = [
    'BasicSchedulingPolicy',
    'BasicSchedulingPolicyPatch',
    'GangSchedulingPolicy',
    'GangSchedulingPolicyPatch',
    'PodGroup',
    'PodGroupPatch',
    'PodGroupPolicy',
    'PodGroupPolicyPatch',
    'PriorityClass',
    'TypedLocalObjectReference',
    'TypedLocalObjectReferencePatch',
    'Workload',
    'WorkloadSpec',
    'WorkloadSpecPatch',
]

@pulumi.output_type
class BasicSchedulingPolicy(dict):
    """
    BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
    """
    def __init__(__self__):
        """
        BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
        """
        pass


@pulumi.output_type
class BasicSchedulingPolicyPatch(dict):
    """
    BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
    """
    def __init__(__self__):
        """
        BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
        """
        pass


@pulumi.output_type
class GangSchedulingPolicy(dict):
    """
    GangSchedulingPolicy defines the parameters for gang scheduling.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "minCount":
            suggest = "min_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GangSchedulingPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GangSchedulingPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GangSchedulingPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 min_count: _builtins.int):
        """
        GangSchedulingPolicy defines the parameters for gang scheduling.

        :param _builtins.int min_count: MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        pulumi.set(__self__, "min_count", min_count)

    @_builtins.property
    @pulumi.getter(name="minCount")
    def min_count(self) -> _builtins.int:
        """
        MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        return pulumi.get(self, "min_count")


@pulumi.output_type
class GangSchedulingPolicyPatch(dict):
    """
    GangSchedulingPolicy defines the parameters for gang scheduling.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "minCount":
            suggest = "min_count"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GangSchedulingPolicyPatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GangSchedulingPolicyPatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GangSchedulingPolicyPatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 min_count: Optional[_builtins.int] = None):
        """
        GangSchedulingPolicy defines the parameters for gang scheduling.

        :param _builtins.int min_count: MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        if min_count is not None:
            pulumi.set(__self__, "min_count", min_count)

    @_builtins.property
    @pulumi.getter(name="minCount")
    def min_count(self) -> Optional[_builtins.int]:
        """
        MinCount is the minimum number of pods that must be schedulable or scheduled at the same time for the scheduler to admit the entire group. It must be a positive integer.
        """
        return pulumi.get(self, "min_count")


@pulumi.output_type
class PodGroup(dict):
    """
    PodGroup represents a set of pods with a common scheduling policy.
    """
    def __init__(__self__, *,
                 name: _builtins.str,
                 policy: 'outputs.PodGroupPolicy'):
        """
        PodGroup represents a set of pods with a common scheduling policy.

        :param _builtins.str name: Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        :param 'PodGroupPolicyArgs' policy: Policy defines the scheduling policy for this PodGroup.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "policy", policy)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def policy(self) -> 'outputs.PodGroupPolicy':
        """
        Policy defines the scheduling policy for this PodGroup.
        """
        return pulumi.get(self, "policy")


@pulumi.output_type
class PodGroupPatch(dict):
    """
    PodGroup represents a set of pods with a common scheduling policy.
    """
    def __init__(__self__, *,
                 name: Optional[_builtins.str] = None,
                 policy: Optional['outputs.PodGroupPolicyPatch'] = None):
        """
        PodGroup represents a set of pods with a common scheduling policy.

        :param _builtins.str name: Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        :param 'PodGroupPolicyPatchArgs' policy: Policy defines the scheduling policy for this PodGroup.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name is a unique identifier for the PodGroup within the Workload. It must be a DNS label. This field is immutable.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional['outputs.PodGroupPolicyPatch']:
        """
        Policy defines the scheduling policy for this PodGroup.
        """
        return pulumi.get(self, "policy")


@pulumi.output_type
class PodGroupPolicy(dict):
    """
    PodGroupPolicy defines the scheduling configuration for a PodGroup.
    """
    def __init__(__self__, *,
                 basic: Optional['outputs.BasicSchedulingPolicy'] = None,
                 gang: Optional['outputs.GangSchedulingPolicy'] = None):
        """
        PodGroupPolicy defines the scheduling configuration for a PodGroup.

        :param 'BasicSchedulingPolicyArgs' basic: Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        :param 'GangSchedulingPolicyArgs' gang: Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        if basic is not None:
            pulumi.set(__self__, "basic", basic)
        if gang is not None:
            pulumi.set(__self__, "gang", gang)

    @_builtins.property
    @pulumi.getter
    def basic(self) -> Optional['outputs.BasicSchedulingPolicy']:
        """
        Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        """
        return pulumi.get(self, "basic")

    @_builtins.property
    @pulumi.getter
    def gang(self) -> Optional['outputs.GangSchedulingPolicy']:
        """
        Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        return pulumi.get(self, "gang")


@pulumi.output_type
class PodGroupPolicyPatch(dict):
    """
    PodGroupPolicy defines the scheduling configuration for a PodGroup.
    """
    def __init__(__self__, *,
                 basic: Optional['outputs.BasicSchedulingPolicyPatch'] = None,
                 gang: Optional['outputs.GangSchedulingPolicyPatch'] = None):
        """
        PodGroupPolicy defines the scheduling configuration for a PodGroup.

        :param 'BasicSchedulingPolicyPatchArgs' basic: Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        :param 'GangSchedulingPolicyPatchArgs' gang: Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        if basic is not None:
            pulumi.set(__self__, "basic", basic)
        if gang is not None:
            pulumi.set(__self__, "gang", gang)

    @_builtins.property
    @pulumi.getter
    def basic(self) -> Optional['outputs.BasicSchedulingPolicyPatch']:
        """
        Basic specifies that the pods in this group should be scheduled using standard Kubernetes scheduling behavior.
        """
        return pulumi.get(self, "basic")

    @_builtins.property
    @pulumi.getter
    def gang(self) -> Optional['outputs.GangSchedulingPolicyPatch']:
        """
        Gang specifies that the pods in this group should be scheduled using all-or-nothing semantics.
        """
        return pulumi.get(self, "gang")


@pulumi.output_type
class PriorityClass(dict):
    """
    DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiVersion":
            suggest = "api_version"
        elif key == "globalDefault":
            suggest = "global_default"
        elif key == "preemptionPolicy":
            suggest = "preemption_policy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PriorityClass. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PriorityClass.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PriorityClass.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 value: _builtins.int,
                 api_version: Optional[_builtins.str] = None,
                 description: Optional[_builtins.str] = None,
                 global_default: Optional[_builtins.bool] = None,
                 kind: Optional[_builtins.str] = None,
                 metadata: Optional['_meta.v1.outputs.ObjectMeta'] = None,
                 preemption_policy: Optional[_builtins.str] = None):
        """
        DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.

        :param _builtins.int value: The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
        :param _builtins.str api_version: APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        :param _builtins.str description: description is an arbitrary string that usually provides guidelines on when this priority class should be used.
        :param _builtins.bool global_default: globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
        :param _builtins.str kind: Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        :param '_meta.v1.ObjectMetaArgs' metadata: Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        :param _builtins.str preemption_policy: PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is alpha-level and is only honored by servers that enable the NonPreemptingPriority feature.
        """
        pulumi.set(__self__, "value", value)
        if api_version is not None:
            pulumi.set(__self__, "api_version", 'scheduling.k8s.io/v1alpha1')
        if description is not None:
            pulumi.set(__self__, "description", description)
        if global_default is not None:
            pulumi.set(__self__, "global_default", global_default)
        if kind is not None:
            pulumi.set(__self__, "kind", 'PriorityClass')
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if preemption_policy is not None:
            pulumi.set(__self__, "preemption_policy", preemption_policy)

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.int:
        """
        The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[_builtins.str]:
        """
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        description is an arbitrary string that usually provides guidelines on when this priority class should be used.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="globalDefault")
    def global_default(self) -> Optional[_builtins.bool]:
        """
        globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
        """
        return pulumi.get(self, "global_default")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[_builtins.str]:
        """
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional['_meta.v1.outputs.ObjectMeta']:
        """
        Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter(name="preemptionPolicy")
    def preemption_policy(self) -> Optional[_builtins.str]:
        """
        PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is alpha-level and is only honored by servers that enable the NonPreemptingPriority feature.
        """
        return pulumi.get(self, "preemption_policy")


@pulumi.output_type
class TypedLocalObjectReference(dict):
    """
    TypedLocalObjectReference allows to reference typed object inside the same namespace.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiGroup":
            suggest = "api_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TypedLocalObjectReference. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TypedLocalObjectReference.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TypedLocalObjectReference.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 kind: _builtins.str,
                 name: _builtins.str,
                 api_group: Optional[_builtins.str] = None):
        """
        TypedLocalObjectReference allows to reference typed object inside the same namespace.

        :param _builtins.str kind: Kind is the type of resource being referenced. It must be a path segment name.
        :param _builtins.str name: Name is the name of resource being referenced. It must be a path segment name.
        :param _builtins.str api_group: APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        """
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "name", name)
        if api_group is not None:
            pulumi.set(__self__, "api_group", api_group)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> _builtins.str:
        """
        Kind is the type of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name is the name of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="apiGroup")
    def api_group(self) -> Optional[_builtins.str]:
        """
        APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        """
        return pulumi.get(self, "api_group")


@pulumi.output_type
class TypedLocalObjectReferencePatch(dict):
    """
    TypedLocalObjectReference allows to reference typed object inside the same namespace.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiGroup":
            suggest = "api_group"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TypedLocalObjectReferencePatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TypedLocalObjectReferencePatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TypedLocalObjectReferencePatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 api_group: Optional[_builtins.str] = None,
                 kind: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None):
        """
        TypedLocalObjectReference allows to reference typed object inside the same namespace.

        :param _builtins.str api_group: APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        :param _builtins.str kind: Kind is the type of resource being referenced. It must be a path segment name.
        :param _builtins.str name: Name is the name of resource being referenced. It must be a path segment name.
        """
        if api_group is not None:
            pulumi.set(__self__, "api_group", api_group)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="apiGroup")
    def api_group(self) -> Optional[_builtins.str]:
        """
        APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
        """
        return pulumi.get(self, "api_group")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[_builtins.str]:
        """
        Kind is the type of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name is the name of resource being referenced. It must be a path segment name.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class Workload(dict):
    """
    Workload allows for expressing scheduling constraints that should be used when managing lifecycle of workloads from scheduling perspective, including scheduling, preemption, eviction and other phases.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiVersion":
            suggest = "api_version"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in Workload. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        Workload.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        Workload.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 spec: 'outputs.WorkloadSpec',
                 api_version: Optional[_builtins.str] = None,
                 kind: Optional[_builtins.str] = None,
                 metadata: Optional['_meta.v1.outputs.ObjectMeta'] = None):
        """
        Workload allows for expressing scheduling constraints that should be used when managing lifecycle of workloads from scheduling perspective, including scheduling, preemption, eviction and other phases.

        :param 'WorkloadSpecArgs' spec: Spec defines the desired behavior of a Workload.
        :param _builtins.str api_version: APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        :param _builtins.str kind: Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        :param '_meta.v1.ObjectMetaArgs' metadata: Standard object's metadata. Name must be a DNS subdomain.
        """
        pulumi.set(__self__, "spec", spec)
        if api_version is not None:
            pulumi.set(__self__, "api_version", 'scheduling.k8s.io/v1alpha1')
        if kind is not None:
            pulumi.set(__self__, "kind", 'Workload')
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> 'outputs.WorkloadSpec':
        """
        Spec defines the desired behavior of a Workload.
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[_builtins.str]:
        """
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[_builtins.str]:
        """
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional['_meta.v1.outputs.ObjectMeta']:
        """
        Standard object's metadata. Name must be a DNS subdomain.
        """
        return pulumi.get(self, "metadata")


@pulumi.output_type
class WorkloadSpec(dict):
    """
    WorkloadSpec defines the desired state of a Workload.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "podGroups":
            suggest = "pod_groups"
        elif key == "controllerRef":
            suggest = "controller_ref"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadSpec. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadSpec.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadSpec.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 pod_groups: Sequence['outputs.PodGroup'],
                 controller_ref: Optional['outputs.TypedLocalObjectReference'] = None):
        """
        WorkloadSpec defines the desired state of a Workload.

        :param Sequence['PodGroupArgs'] pod_groups: PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        :param 'TypedLocalObjectReferenceArgs' controller_ref: ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        """
        pulumi.set(__self__, "pod_groups", pod_groups)
        if controller_ref is not None:
            pulumi.set(__self__, "controller_ref", controller_ref)

    @_builtins.property
    @pulumi.getter(name="podGroups")
    def pod_groups(self) -> Sequence['outputs.PodGroup']:
        """
        PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        """
        return pulumi.get(self, "pod_groups")

    @_builtins.property
    @pulumi.getter(name="controllerRef")
    def controller_ref(self) -> Optional['outputs.TypedLocalObjectReference']:
        """
        ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        """
        return pulumi.get(self, "controller_ref")


@pulumi.output_type
class WorkloadSpecPatch(dict):
    """
    WorkloadSpec defines the desired state of a Workload.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "controllerRef":
            suggest = "controller_ref"
        elif key == "podGroups":
            suggest = "pod_groups"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadSpecPatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadSpecPatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadSpecPatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 controller_ref: Optional['outputs.TypedLocalObjectReferencePatch'] = None,
                 pod_groups: Optional[Sequence['outputs.PodGroupPatch']] = None):
        """
        WorkloadSpec defines the desired state of a Workload.

        :param 'TypedLocalObjectReferencePatchArgs' controller_ref: ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        :param Sequence['PodGroupPatchArgs'] pod_groups: PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        """
        if controller_ref is not None:
            pulumi.set(__self__, "controller_ref", controller_ref)
        if pod_groups is not None:
            pulumi.set(__self__, "pod_groups", pod_groups)

    @_builtins.property
    @pulumi.getter(name="controllerRef")
    def controller_ref(self) -> Optional['outputs.TypedLocalObjectReferencePatch']:
        """
        ControllerRef is an optional reference to the controlling object, such as a Deployment or Job. This field is intended for use by tools like CLIs to provide a link back to the original workload definition. When set, it cannot be changed.
        """
        return pulumi.get(self, "controller_ref")

    @_builtins.property
    @pulumi.getter(name="podGroups")
    def pod_groups(self) -> Optional[Sequence['outputs.PodGroupPatch']]:
        """
        PodGroups is the list of pod groups that make up the Workload. The maximum number of pod groups is 8. This field is immutable.
        """
        return pulumi.get(self, "pod_groups")


